@@ -25,6 +25,11 @@ import requests  # type: ignore
 import validators  # type: ignore
 
 from ..config import AVAILABLE_AUDIO_FORMATS, AVAILABLE_GENERIC_FORMATS, REQUEST_TIMEOUT
+from .utils import (
+    _get_assembly_utterances,
+    _get_deepgram_utterances,
+    _get_rev_monologues,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -143,7 +148,7 @@ class BaseSource:
 
         return True
 
-    def prepare_payload(self) -> Union[str, Dict[str, bytes]]:
+    def prepare_payload(self) -> Union[str, bytes, Dict[str, bytes]]:
         """Prepare payload."""
         raise NotImplementedError("Payload preparation is not implemented yet.")
 
@@ -378,7 +383,32 @@ class AudioSource(BaseSource):
 
 @dataclass
 class WordcabTranscriptSource:
-    """Wordcab transcript source object."""
+    """
+    Wordcab transcript source object using a Wordcab transcript ID.
+
+    Parameters
+    ----------
+    transcript_id : str
+        The Wordcab transcript ID to use as input.
+
+    Raises
+    ------
+    ValueError
+        If the `transcript_id` is not provided.
+
+    Examples
+    --------
+    >>> from wordcab.core_objects import WordcabTranscriptSource
+
+    >>> wordcab_transcript_source = WordcabTranscriptSource(transcript_id="transcript_12345")
+    >>> wordcab_transcript_source
+    WordcabTranscriptSource(transcript_id=transcript_12345)
+
+    Returns
+    -------
+    WordcabTranscriptSource
+        The Wordcab transcript source object.
+    """
 
     transcript_id: Optional[str] = field(default=None)
     source: str = field(init=False)
@@ -421,43 +451,254 @@ class SignedURLSource(BaseSource):
 
 @dataclass
 class AssemblyAISource(BaseSource):
-    """AssemblyAI source object."""
+    """
+    AssemblyAI source object using a local or remote AssemblyAI JSON file.
+
+    Parameters
+    ----------
+    filepath : Union[str, Path]
+        The path to the local file.
+    url : str
+        The URL to the remote file.
+
+    Raises
+    ------
+    ValueError
+        If the file format is not valid.
+
+    Examples
+    --------
+    >>> from wordcab.core_objects import AssemblyAISource
+
+    >>> assemblyai_source = AssemblyAISource(filepath="path/to/assemblyai/file.json")  # doctest: +SKIP
+    >>> assemblyai_source  # doctest: +SKIP
+    AssemblyAISource(...)
+    >>> assemblyai_source.source  # doctest: +SKIP
+    'assembly_ai'
+
+    Returns
+    -------
+    AssemblyAISource
+        The AssemblyAI source object.
+    """
 
     def __post_init__(self) -> None:
         """Post-init method."""
         super().__post_init__()
         self.source = "assembly_ai"
-        raise NotImplementedError("AssemblyAI source is not implemented yet.")
+
+        if self._suffix != ".json":
+            raise ValueError(
+                f"Please provide a valid AssemblyAI file format. {self._suffix} is not valid, it should be .json."
+            )
+
+        if self.source_type == "local":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
+            self.file_object = self._load_file_from_url()
+
+    def prepare_payload(self) -> str:
+        """Prepare payload for API request."""
+        self.payload = json.dumps(
+            _get_assembly_utterances(json.loads(self.file_object))
+        )
+        return self.payload
+
+    def prepare_headers(self) -> Dict[str, str]:
+        """Prepare headers for API request."""
+        self.headers = {
+            "Accept": "application/json",
+            "Content-Type": "application/json",
+        }
+        return self.headers
 
 
 @dataclass
 class DeepgramSource(BaseSource):
-    """Deepgram source object."""
+    """
+    Deepgram source object using a local or remote Deepgram JSON file.
+
+    Parameters
+    ----------
+    filepath : Union[str, Path]
+        The path to the local file.
+    url : str
+        The URL to the remote file.
+
+    Raises
+    ------
+    ValueError
+        If the file format is not valid.
+
+    Examples
+    --------
+    >>> from wordcab.core_objects import DeepgramSource
+
+    >>> deepgram_source = DeepgramSource(filepath="path/to/deepgram/file.json")  # doctest: +SKIP
+    >>> deepgram_source  # doctest: +SKIP
+    DeepgramSource(...)
+    >>> deepgram_source.source  # doctest: +SKIP
+    'deepgram'
+
+    Returns
+    -------
+    DeepgramSource
+        The Deepgram source object.
+    """
 
     def __post_init__(self) -> None:
         """Post-init method."""
         super().__post_init__()
         self.source = "deepgram"
-        raise NotImplementedError("Deepgram source is not implemented yet.")
+
+        if self._suffix != ".json":
+            raise ValueError(
+                f"Please provide a valid Deepgram file format. {self._suffix} is not valid, it should be .json."
+            )
+
+        if self.source_type == "local":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
+            self.file_object = self._load_file_from_url()
+
+    def prepare_payload(self) -> str:
+        """Prepare payload for API request."""
+        self.payload = json.dumps(
+            _get_deepgram_utterances(json.loads(self.file_object))
+        )
+        return self.payload
+
+    def prepare_headers(self) -> Dict[str, str]:
+        """Prepare headers for API request."""
+        self.headers = {
+            "Accept": "application/json",
+            "Content-Type": "application/json",
+        }
+        return self.headers
 
 
 @dataclass
 class RevSource(BaseSource):
-    """Rev.ai source object."""
+    """
+    Rev.ai source object using a local or remote Rev.ai JSON file.
+
+    Parameters
+    ----------
+    filepath : Union[str, Path]
+        The path to the local file.
+    url : str
+        The URL to the remote file.
+
+    Raises
+    ------
+    ValueError
+        If the file format is not valid.
+
+    Examples
+    --------
+    >>> from wordcab.core_objects import RevSource
+
+    >>> rev_source = RevSource(filepath="path/to/rev/file.json")  # doctest: +SKIP
+    >>> rev_source  # doctest: +SKIP
+    RevSource(...)
+    >>> rev_source.source  # doctest: +SKIP
+    'rev_ai'
+
+    Returns
+    -------
+    RevSource
+        The Rev.ai source object.
+    """
 
     def __post_init__(self) -> None:
         """Post-init method."""
         super().__post_init__()
         self.source = "rev_ai"
-        raise NotImplementedError("Rev.ai source is not implemented yet.")
+
+        if self._suffix != ".json":
+            raise ValueError(
+                f"Please provide a valid Rev.ai file format. {self._suffix} is not valid, it should be .json."
+            )
+
+        if self.source_type == "local":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
+            self.file_object = self._load_file_from_url()
+
+    def prepare_payload(self) -> str:
+        """Prepare payload for API request."""
+        self.payload = json.dumps(_get_rev_monologues(json.loads(self.file_object)))
+        return self.payload
+
+    def prepare_headers(self) -> Dict[str, str]:
+        """Prepare headers for API request."""
+        self.headers = {
+            "Accept": "application/json",
+            "Content-Type": "application/json",
+        }
+        return self.headers
 
 
 @dataclass
 class VTTSource(BaseSource):
-    """VTT source object."""
+    """
+    VTT source object using a local or remote VTT file.
+
+    Parameters
+    ----------
+    filepath : Union[str, Path]
+        The path to the local file.
+    url : str
+        The URL to the remote file.
+
+    Raises
+    ------
+    ValueError
+        If the file format is not valid.
+
+    Examples
+    --------
+    >>> from wordcab.core_objects import VTTSource
+
+    >>> vtt_source = VTTSource(filepath="path/to/vtt/file.vtt")  # doctest: +SKIP
+    >>> vtt_source  # doctest: +SKIP
+    VTTSource(...)
+    >>> vtt_source.source  # doctest: +SKIP
+    'vtt'
+
+    Returns
+    -------
+    VTTSource
+        The VTT source object.
+    """
+
+    filename: str = field(init=False)
 
     def __post_init__(self) -> None:
         """Post-init method."""
         super().__post_init__()
         self.source = "vtt"
-        raise NotImplementedError("VTT source is not implemented yet.")
+
+        if self._suffix != ".vtt":
+            raise ValueError(
+                f"Please provide a valid VTT file format. {self._suffix} is not valid, it should be .vtt."
+            )
+
+        if self.source_type == "local":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
+            self.file_object = self._load_file_from_url()
+
+        self.filename = self.filepath.name  # type: ignore
+
+    def prepare_payload(self) -> bytes:
+        """Prepare payload for API request."""
+        self.payload: bytes = self.file_object
+        return self.payload
+
+    def prepare_headers(self) -> Dict[str, str]:
+        """Prepare headers for API request."""
+        self.headers = {
+            "Content-Disposition": f"attachment; filename={self.filename}",
+        }
+        return self.headers
